summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--mullvad-types/src/wireguard.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/mullvad-types/src/wireguard.rs b/mullvad-types/src/wireguard.rs
index 008b7a475c..1af50abadc 100644
--- a/mullvad-types/src/wireguard.rs
+++ b/mullvad-types/src/wireguard.rs
@@ -9,9 +9,9 @@ pub const MAX_ROTATION_INTERVAL: Duration = Duration::from_secs(30 * 24 * 60 * 6
pub const DEFAULT_ROTATION_INTERVAL: Duration = MAX_ROTATION_INTERVAL;
/// Whether to enable or disable quantum resistant tunnels when the setting is set to
-/// `QuantumResistantState::Auto`. It is currently enabled by default on Linux but disabled on all
-/// other platforms.
-const QUANTUM_RESISTANT_AUTO_STATE: bool = cfg!(target_os = "linux");
+/// `QuantumResistantState::Auto`. It is currently enabled by default on Linux and macOS,
+/// but disabled on all other platforms.
+const QUANTUM_RESISTANT_AUTO_STATE: bool = cfg!(any(target_os = "linux", target_os = "macos"));
#[derive(Serialize, Deserialize, Copy, Clone, Debug, PartialEq, Eq)]
#[serde(rename_all = "lowercase")]